use std::sync::OnceLock;

use askama::Template;
use blake3::Hash;

use crate::{RuntimeModule, common::materials::MaterialDrops, create_file, create_hashes};

const MATERIAL_KINDS: &[&str] = &[
	"lucid", "spirit", "power", "blaze", "frost", "thunder", "shiny", "bright", "mystery", "gale",
	"mythril",
];
const DROPS_PATH: &str = "./input/kh1/drops";
static JS_HASH: OnceLock<Hash> = OnceLock::new();

#[derive(Template)]
#[template(path = "pages/kh1/drops.html")]
struct DropsTemplate {
	pub drops: Vec<MaterialDrops>,
}

pub struct Module;

impl RuntimeModule for Module {
	fn start_module() {
		tracing::info!("Loading enemy drops data from {}", DROPS_PATH);
		let drops = MaterialDrops::import(DROPS_PATH);

		tracing::info!("Generating the KH1 drops template");
		let drops_template = DropsTemplate { drops };

		create_file("./out/kh1", "drops", drops_template.render().unwrap()).unwrap();
	}

	fn get_js_hash() -> String {
		JS_HASH.get_or_init(|| create_hashes("kh1")).to_string()
	}
}
